<?php
/**
 * Plugin Name: Gestion de la home
 * Plugin URI:
 * Description: Plugin permettant de gérer la page d'accueil
 * Version: Version 1.0
 * Author: Steven Humbert
 * Author URI:  http://www.comcicomca.com/
 * License: GPL2 license
 */

### No direct access.

require_once 'home-custom-functions.php';

register_activation_hook(__FILE__, 'home_activation_hook');

function OptionHome() {
    add_menu_page('Gestion page d\'accueil', 'Home', '','gestion_home', '#', '' ,2);
    add_submenu_page('gestion_home', 'Description du site', 'Description du site', 'manage_options', 'home/description_site.php','');
    add_submenu_page('gestion_home', 'Noms des blocs', 'Noms des blocs', 'manage_options', 'home/titre_des_blocs.php','');
    add_submenu_page('gestion_home', 'Affichage dans les blocs', 'Affichage dans les blocs', 'manage_options', 'home/article_une.php','');
    add_submenu_page('gestion_home', 'Bloc : Actus', 'Bloc : Actus', 'manage_options', 'home/liste_actualite.php','');
    add_submenu_page('gestion_home', 'Bloc : FAQ', 'Bloc : FAQ', 'manage_options', 'home/faq_choix.php','');
    add_submenu_page('gestion_home', 'Bloc : Dossier', 'Bloc : Dossier', 'manage_options', 'home/dossier.php','');
    add_action('admin_menu', 'cccc_custom_remove_meta_boxes');
    //add_action('admin_init', 'cccc_custom_remove_menu_pages');
    //add_action('wp_before_admin_bar_render', 'cccc_custom_remove_menu_bar_items');
    add_action('admin_print_scripts', 'cccc_custom_upload_button_scripts');
    add_action('admin_print_styles', 'cccc_custom_upload_button_styles');
}
// add_action('admin_menu', 'OptionHome');


if(isset($_POST['valider_article_une']))
{
    if(save_article_une($_POST['id_article']))
    {
       $_SESSION['home_warning_message']['notice'][] = __('Article à la une mise à jour');
    }
    else
    {
       $_SESSION['home_warning_message']['error'][] = __('Erreur lors de la mise à jour de l\'article');
    }
}

if(isset($_POST['valider_mode_affichage_actu']))
{
    if(save_mode_affichage($_POST['type_affichage']))
    {
       $_SESSION['home_warning_message']['notice'][] = __('Mode d\'affichage mis à jour');
    }
    else
    {
       $_SESSION['home_warning_message']['error'][] = __('Erreur lors de la mise à jour du mode d\'affichage');
    }

}

if(isset($_POST['article_actu']))
{
    if (get_mode_affichage() == 'one') {
        if (isset($_POST['choix_video_actu']) || isset($_POST['choix_video_actu_ss'])) {
            if (isset($_POST['choix_video_actu']))
                update_option('choix_video_actu', $_POST['choix_video_actu']);

            if (isset($_POST['choix_video_actu_ss']))
                update_option('choix_video_actu_ss', $_POST['choix_video_actu_ss']);
        }
        if (isset($_POST['actu_youtube']) || isset($_POST['actu_youtube_ss'])) {
            if (isset($_POST['actu_youtube']))
                update_option('actu_youtube', $_POST['actu_youtube']);

            if (isset($_POST['actu_youtube_ss']))
                update_option('actu_youtube_ss', $_POST['actu_youtube_ss']);
        }
        $_SESSION['home_warning_message']['notice'][] = __('Actus mis à jour');
    } else {
        if (isset($_POST['choix_article_actu'])) {
            if (save_actu_article($_POST['choix_article_actu']))
                $_SESSION['home_warning_message']['notice'][] = __('l\'article pour les actus à bien été ajouté');
            else
                $_SESSION['home_warning_message']['error'][] = __('Erreur lors de l\'ajout de l\'article');
        }
    }
}

if(isset($_POST['article_dossier']))
{
    if(isset($_POST['choix_dossier']))
    {
        save_dossier($_POST['choix_dossier']);
        update_option('vignette_document',$_POST['vignette_document']);
        update_option('titre_lien_telechargement_dossier',$_POST['titre_lien_telechargement_dossier']);
    }
}


if(isset($_POST['enregistrer_bloc']))
{
    save_nom_actu($_POST['bloc']);
}

if(isset($_POST['enregistrer_faq']))
{
    save_faq($_POST['choix_faq']);
}


if(isset($_POST['description_btn']))
{
    save_description($_POST['description']);
}

 ?>